@@ -185,7 +185,7 @@
     </message>
     <message>
         <source>Unable to connect. Check internet connection.</source>
-        <translation>Nie można połączyć z siecią. Sprawadź połączenie z Internetem.</translation>
+        <translation type="obsolete">Nie można połączyć z siecią. Sprawadź połączenie z Internetem.</translation>
     </message>
     <message>
         <source>Unknown error: </source>
@@ -195,6 +195,10 @@
         <source>Connecting...</source>
         <translation>Łączenie...</translation>
     </message>
+    <message>
+        <source>Unable to connect. Check internet connection and restart application.</source>
+        <translation>Nie można połączyć z siecią. Sprawadź połączenie z Internetem i zrestartuj aplikacje.</translation>
+    </message>
 </context>
 <context>
     <name>LoginPage</name>
@@ -409,19 +413,19 @@
     <name>StartPage</name>
     <message>
         <source>About Ubi</source>
-        <translation>O Ubi</translation>
+        <translation type="obsolete">O Ubi</translation>
     </message>
     <message>
         <source>Files</source>
-        <translation>Pliki</translation>
+        <translation type="obsolete">Pliki</translation>
     </message>
     <message>
         <source>Account</source>
-        <translation>Konto</translation>
+        <translation type="obsolete">Konto</translation>
     </message>
     <message>
         <source>Settings</source>
-        <translation>Ustawienia</translation>
+        <translation type="obsolete">Ustawienia</translation>
     </message>
     <message>
         <source>&lt;b&gt;Ubi&lt;/b&gt; 1.0.0&lt;br/&gt;Ubuntu One client for Maemo 5&lt;br/&gt;&lt;small&gt;Copyright © 2012 Michal Kosciesza&lt;/small&gt;</source>
@@ -441,11 +445,11 @@
     </message>
     <message>
         <source>&lt;b&gt;Ubi&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Ubi&lt;/b&gt;</translation>
+        <translation type="obsolete">&lt;b&gt;Ubi&lt;/b&gt;</translation>
     </message>
     <message>
         <source>&lt;p&gt;An unofficial Ubuntu One app for Maemo 5 and other Qt-enabled platforms.&lt;/p&gt;&lt;p&gt;&lt;small&gt;http://ubi.garage.maemo.org&lt;/small&gt;&lt;/p&gt;&lt;p&gt;&lt;small&gt;© 2012 Michal Kosciesza&lt;/small&gt;&lt;/p&gt;</source>
-        <translation>&lt;p&gt;Nieoficjalna aplikacja Ubuntu One dla Maemo 5 i innych platform obsługujących Qt.&lt;/p&gt;&lt;p&gt;&lt;small&gt;http://ubi.garage.maemo.org&lt;/small&gt;&lt;/p&gt;&lt;p&gt;&lt;small&gt;© 2012 Michal Kosciesza&lt;/small&gt;&lt;/p&gt;</translation>
+        <translation type="obsolete">&lt;p&gt;Nieoficjalna aplikacja Ubuntu One dla Maemo 5 i innych platform obsługujących Qt.&lt;/p&gt;&lt;p&gt;&lt;small&gt;http://ubi.garage.maemo.org&lt;/small&gt;&lt;/p&gt;&lt;p&gt;&lt;small&gt;© 2012 Michal Kosciesza&lt;/small&gt;&lt;/p&gt;</translation>
     </message>
 </context>
 <context>
@@ -495,7 +499,7 @@
     </message>
     <message>
         <source>&lt;p&gt;An unofficial Ubuntu One app for Maemo 5 and other Qt-enabled platforms.&lt;/p&gt;&lt;p&gt;&lt;small&gt;http://ubi.garage.maemo.org&lt;/small&gt;&lt;/p&gt;&lt;p&gt;&lt;small&gt;© 2012 Michal Kosciesza&lt;/small&gt;&lt;/p&gt;</source>
-        <translation>&lt;p&gt;Nieoficjalna aplikacja Ubuntu One dla Maemo 5 i innych platform obsługujących Qt.&lt;/p&gt;&lt;p&gt;&lt;small&gt;http://ubi.garage.maemo.org&lt;/small&gt;&lt;/p&gt;&lt;p&gt;&lt;small&gt;© 2012 Michal Kosciesza&lt;/small&gt;&lt;/p&gt;</translation>
+        <translation type="obsolete">&lt;p&gt;Nieoficjalna aplikacja Ubuntu One dla Maemo 5 i innych platform obsługujących Qt.&lt;/p&gt;&lt;p&gt;&lt;small&gt;http://ubi.garage.maemo.org&lt;/small&gt;&lt;/p&gt;&lt;p&gt;&lt;small&gt;© 2012 Michal Kosciesza&lt;/small&gt;&lt;/p&gt;</translation>
     </message>
     <message>
         <source>File downloaded.</source>
@@ -521,5 +525,48 @@
         <source>File operation canceled.</source>
         <translation>Operacja anulowana.</translation>
     </message>
+    <message>
+        <source>&lt;p&gt;An unofficial Ubuntu One app for Maemo/Meego and other Qt-enabled platforms.&lt;/p&gt;&lt;p&gt;&lt;small&gt;http://ubi.garage.maemo.org&lt;/small&gt;&lt;/p&gt;&lt;p&gt;&lt;small&gt;© 2012 Michal Kosciesza&lt;/small&gt;&lt;/p&gt;</source>
+        <translation>&lt;p&gt;Nieoficjalna aplikacja Ubuntu One dla Maemo/Meego i innych platform obsługujących Qt.&lt;/p&gt;&lt;p&gt;&lt;small&gt;http://ubi.garage.maemo.org&lt;/small&gt;&lt;/p&gt;&lt;p&gt;&lt;small&gt;© 2012 Michal Kosciesza&lt;/small&gt;&lt;/p&gt;</translation>
+    </message>
+</context>
+<context>
+    <name>meego_main</name>
+    <message>
+        <source>File downloaded.</source>
+        <translation>Plik został pobrany.</translation>
+    </message>
+    <message>
+        <source>File uploaded.</source>
+        <translation>Plik został wysłany.</translation>
+    </message>
+    <message>
+        <source>Error while downloading.</source>
+        <translation>Błąd podczas pobierania.</translation>
+    </message>
+    <message>
+        <source>Error while uploading.</source>
+        <translation>Błąd podczas wysyłania.</translation>
+    </message>
+    <message>
+        <source>File added to the queue.</source>
+        <translation>Plik dodany do kolejki.</translation>
+    </message>
+    <message>
+        <source>File operation canceled.</source>
+        <translation>Operacja anulowana.</translation>
+    </message>
+    <message>
+        <source>&lt;b&gt;Ubi&lt;/b&gt;</source>
+        <translation>&lt;b&gt;Ubi&lt;/b&gt;</translation>
+    </message>
+    <message>
+        <source>&lt;p&gt;An unofficial Ubuntu One app for Maemo 5 and other Qt-enabled platforms.&lt;/p&gt;&lt;p&gt;&lt;small&gt;http://ubi.garage.maemo.org&lt;/small&gt;&lt;/p&gt;&lt;p&gt;&lt;small&gt;© 2012 Michal Kosciesza&lt;/small&gt;&lt;/p&gt;</source>
+        <translation type="obsolete">&lt;p&gt;Nieoficjalna aplikacja Ubuntu One dla Maemo 5 i innych platform obsługujących Qt.&lt;/p&gt;&lt;p&gt;&lt;small&gt;http://ubi.garage.maemo.org&lt;/small&gt;&lt;/p&gt;&lt;p&gt;&lt;small&gt;© 2012 Michal Kosciesza&lt;/small&gt;&lt;/p&gt;</translation>
+    </message>
+    <message>
+        <source>&lt;p&gt;An unofficial Ubuntu One app for Maemo/Meego and other Qt-enabled platforms.&lt;/p&gt;&lt;p&gt;&lt;small&gt;http://ubi.garage.maemo.org&lt;/small&gt;&lt;/p&gt;&lt;p&gt;&lt;small&gt;© 2012 Michal Kosciesza&lt;/small&gt;&lt;/p&gt;</source>
+        <translation>&lt;p&gt;Nieoficjalna aplikacja Ubuntu One dla Maemo/Meego i innych platform obsługujących Qt.&lt;/p&gt;&lt;p&gt;&lt;small&gt;http://ubi.garage.maemo.org&lt;/small&gt;&lt;/p&gt;&lt;p&gt;&lt;small&gt;© 2012 Michal Kosciesza&lt;/small&gt;&lt;/p&gt;</translation>
+    </message>
 </context>
 </TS>
